"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.TestScenarioBuilder = void 0;
/**
 * The builder helps the creation of {@link TestScenario}.
 */
class TestScenarioBuilder {
    constructor(_name, _configure, _before, 
    // eslint-disable-next-line @typescript-eslint/no-empty-function
    _execute = () => { }, _after) {
        this._name = _name;
        this._configure = _configure;
        this._before = _before;
        this._execute = _execute;
        this._after = _after;
    }
    /**
     * Get a new builder.
     * @param name the name of the scenario
     */
    static get(name) {
        return new TestScenarioBuilder(name);
    }
    /**
     * Define the {@link TestScenario.configure} method.
     * @param cb the callback
     */
    configure(cb) {
        this._configure = cb;
        return this;
    }
    /**
     * Define the {@link TestScenario.before} method.
     * @param cb the callback
     */
    before(cb) {
        this._before = cb;
        return this;
    }
    /**
     * Define the {@link TestScenario.execute} method.
     * @param cb the callback
     */
    execute(cb) {
        this._execute = cb;
        return this;
    }
    /**
     * Define the {@link TestScenario.after} method.
     * @param cb the callback
     */
    after(cb) {
        this._after = cb;
        return this;
    }
    /**
     * Build the scenario and return it.
     */
    build() {
        return {
            name: this._name,
            configure: this._configure,
            before: this._before,
            execute: this._execute,
            after: this._after,
        };
    }
}
exports.TestScenarioBuilder = TestScenarioBuilder;
//# sourceMappingURL=scenario.js.map